Contributing
============

Welcome! We are thrilled you are interested in contributing to Starsim.
This document will help you get started.

-   We are serious about inclusion and believe the open-source software
    community still has a long way to go. The Starsim community follows
    a [code of
    conduct](https://docs.idmod.org/projects/starsim/en/stable/conduct.html).
    By participating in this project, you agree to abide by its terms.
-   Take a look at our house [style
    guide](https://github.com/starsimhub/styleguide). Starsim more or
    less follows Google's Python style guide, but with some exceptions.
-   Feel free to [open an
    issue](https://github.com/starsimhub/starsim/issues/new/choose) on
    more or less anything! This project is small enough that we don't
    need a formal triage system.
-   Pull requests should be made against `main`. In addition to
    following the [style
    guide](https://github.com/starsimhub/styleguide), please make sure
    the tests pass (`run_tests` in the `tests` folder; they also run via
    GitHub actions).

If you have any other questions, please reach out to us:
<info@starsim.org>. Thank you!
